@@ -24,9 +24,14 @@
 #define __GMIME_H__
 
 #include <glib.h>
+#include "gmime-charset.h"
+#include "gmime-iconv.h"
+#include "gmime-iconv-utils.h"
 #include "gmime-param.h"
 #include "gmime-content-type.h"
+#include "gmime-disposition.h"
 #include "gmime-data-wrapper.h"
+#include "gmime-object.h"
 #include "gmime-part.h"
 #include "gmime-message.h"
 #include "internet-address.h"
@@ -38,13 +43,19 @@
 #include "gmime-stream-filter.h"
 #include "gmime-stream-fs.h"
 #include "gmime-stream-mem.h"
+#include "gmime-stream-mmap.h"
+#include "gmime-stream-null.h"
 #include "gmime-filter.h"
 #include "gmime-filter-basic.h"
+#include "gmime-filter-charset.h"
 #include "gmime-filter-crlf.h"
+#include "gmime-filter-from.h"
+#include "gmime-filter-html.h"
+#include "gmime-filter-yenc.h"
 
 /* GMIME version */
 static const guint gmime_major_version = 0;
-static const guint gmime_minor_version = 7;
+static const guint gmime_minor_version = 9;
 static const guint gmime_micro_version = 0;
 static const guint gmime_interface_age = 0;
 static const guint gmime_binary_age    = 0;
@@ -55,4 +66,8 @@ static const guint gmime_binary_age    = 0;
      (gmime_major_version == (major) && gmime_minor_version == (minor) && \
       gmime_micro_version >= (micro)))
 
+#define GMIME_INIT_FLAG_UTF8  (1 << 0)
+
+void g_mime_init (guint32 flags);
+
 #endif /* __GMIME_H__ */
